@@ -4,9 +4,5 @@ from b_aws_dynamodb_backup.db_actions.seed_db import SeedDb
 
 
 def main():
-    try:
-        table_name = sys.argv[1]
-    except IndexError:
-        table_name = None
-
+    table_name = sys.argv[1]
     SeedDb().seed(table_name, 500)
